.. _design:

Design of Synthetic Data Generator
==================================================

.. toctree::
    :maxdepth: 2

    Architecture <architecture>
    Our motivation of this project <motivation>
